
# Slot: version




URI: [biolink:version](https://w3id.org/biolink/vocab/version)


## Domain and Range

[Dataset](Dataset.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Broad Mappings:** | | pav:version |
|  | | owl:versionInfo |

